subroutine jpdf_scale(r1,r2,nsmp,jpdf,axis1,axis2,dx)

  use glob_vars
  implicit none
  
  ! Input
  integer r1, r2, nsmp
  
  ! Output
  real*8,dimension(nsmp,nsmp) :: jpdf
  real,allocatable :: dv(:,:)
  real*8,dimension(nsmp) :: axis1, axis2
  
  ! Intern
  integer :: nens,j,k,l
  real*8,dimension(2) :: mini,maxi,dx,diff,y0,mean
  real*8,dimension(2,2) :: cov, h_mat, h_inv
  integer,dimension(2) :: ir, ilb, ind, iub
  real*8 epa,d1,d2,det_h
  
  nens = ndp - r2
  allocate(dv(2,nens))
  
  do j=1,nens
    dv(1,j) = x(j+r1) - x(j)
    dv(2,j) = x(j+r2) - x(j)      
  end do
  
  mini = dv(:,1)
  maxi = dv(:,1)
  do j=2,nens
    do k=1,2
      if (dv(k,j) < mini(k)) mini(k) = dv(k,j)
      if (dv(k,j) > maxi(k)) maxi(k) = dv(k,j)
    end do
  end do
!   mini = mini + (maxi-mini)*0.3d0
!   maxi = maxi - (maxi-mini)*0.3d0
!   
  dx = (maxi - mini)/real(nsmp-1)
  
  do j=1,nsmp
    axis1(j) = mini(1) + real(j-1,8)*dx(1)
    axis2(j) = mini(2) + real(j-1,8)*dx(2)
  end do

  mean = 0.0d0
  do j=1,nens
    mean = mean + dv(:,j)
  end do
  mean = mean/real(nens,8)
  
  cov = 0.0d0
  do j=1,nens
    d1 = dv(1,j) - mean(1)
    d2 = dv(2,j) - mean(2)
    cov(1,1) = cov(1,1) + d1*d1
    cov(2,1) = cov(2,1) + d1*d2
    cov(2,2) = cov(2,2) + d2*d2
  end do
  cov(1,2) = cov(2,1)
  cov = cov/real(nens,8)
  
  call sqrt2x2mat(cov(1,1),cov(2,1),cov(2,2),h_mat)
  h_mat = h_mat*real(nens,8)**(-1.0d0/6.0d0)

  det_h = h_mat(1,1)*h_mat(2,2) - h_mat(2,1)*h_mat(1,2)
  
  d1 = h_mat(1,1) + h_mat(2,2)
  ir = int( d1*sqrt(5.0d0)/dx ) + 2
  print*, ir
  
  call inverse2x2mat(h_mat,h_inv)
  
  do j=1,nens
    
    ind = int( (dv(:,j) - mini)/dx ) + 1
    ilb = ind - ir
    iub = ind + ir
    
    do k=1,2
      if (ilb(k) < 1) ilb(k) = 1
      if (iub(k) > nsmp) iub(k) = nsmp
    end do
    
    do k=ilb(1),iub(1)
      y0(1) = axis1(k)
      do l=ilb(2),iub(2)
	y0(2) = axis2(l)
	diff = dv(:,j) - y0
	diff = matmul(h_inv,diff)
	jpdf(k,l) = jpdf(k,l) + epa(diff)
      end do
    end do
    
  end do
  jpdf = jpdf/(real(nens,8)*det_h)
  jpdf = jpdf*(0.08d0/(acos(-1.0d0)))
  
  d1 = 0.0d0
  do j=1,nsmp
    do k=1,nsmp
      d1 = d1 + jpdf(j,k)
    end do
  end do
  d1 = d1*dx(1)*dx(2)
  print*, 'Norm:', d1

end subroutine