module glob_vars

  implicit none
    
  real,allocatable :: x(:)
  integer ndp
  
end module

!====================================================================

! Compile: gfortran scale_analysis.f90 jpdf_scale.f90 sub_cpdf.f90 sqrt2x2mat.f90 inverse2x2mat.f90 -o goscale -O3

program scale_analysis

  use glob_vars
  implicit none
  
  character*80 :: input = 'jfm_data.txt'
    
  integer :: itau = 24
  integer :: tau1 = 24
  integer,parameter :: nsmp = 200
  
  character*80 :: fname
  integer i,j,k,l,ios
  real*8 :: x0, d1, d2
  real*8,dimension(nsmp) :: axis1, axis2,f3
  real*8,dimension(2) :: dx
  real*8,dimension(nsmp,nsmp) :: f13,f12,f23,p13,p23,p12,p13ck,f13ck
  real*8,dimension(nsmp,nsmp) :: f_4tau,p_4tau,pck_it,fck_it
  
  print*, ' '
  print*, 'Lese Daten ...'
  
  open(10,file=input,status='old')
  
  ndp = -1
  ios = 0
  
  do while (ios==0)
    read(10,*,iostat=ios) x0
    ndp=ndp+1 
  end do
  
  rewind(10)
  
  print*, ndp, 'Datenpunkte'
  
  allocate(x(ndp))
  
  do i=1,ndp
    read(10,*) x(i)
  end do
  
  close(10)
  print*, 'Fertig.'
  
  call jpdf_scale(tau1,tau1+2*itau,nsmp,f13,axis1,axis2,dx)
  
!   open(10,file='f_2tau.dat',status='replace')
!   do j=1,nsmp
!     do k=1,nsmp
!       write(10,*) axis1(j), axis2(k), f_2tau(j,k)
!     end do
!     write(10,*) ''
!   end do
!   close(10)
  
  call sub_cpdf(nsmp,f13,p13,dx)
  
!   open(10,file='p_2tau.dat',status='replace')
!   do j=1,nsmp
!     do k=1,nsmp
!       write(10,*) axis1(j), axis2(k), p_2tau(j,k)
!     end do
!     write(10,*) ''
!   end do
!   close(10)

  call jpdf_scale(tau1,tau1+itau,nsmp,f12,axis1,axis2,dx)
  
!   open(10,file='f_12tau.dat',status='replace')
!   do j=1,nsmp
!     do k=1,nsmp
!       write(10,*) axis1(j), axis2(k), f12(j,k)
!     end do
!     write(10,*) ''
!   end do
!   close(10)
!   
  call sub_cpdf(nsmp,f12,p12,dx)
  
!   open(10,file='p_12tau.dat',status='replace')
!   do j=1,nsmp
!     do k=1,nsmp
!       write(10,*) axis1(j), axis2(k), p12(j,k)
!     end do
!     write(10,*) ''
!   end do
!   close(10)

  call jpdf_scale(tau1+itau,tau1+2*itau,nsmp,f23,axis1,axis2,dx)
  call sub_cpdf(nsmp,f23,p23,dx)
  
  p13ck = matmul(p12,p23)
  p13ck = p13ck*dx(1)
  
  f3 = 0.0d0
  do i=1,nsmp
    do j=1,nsmp
      f3(i) = f3(i) + f23(j,i)
    end do
  end do
  f3 = f3*dx(2)
  
  do i=1,nsmp
    do j=1,nsmp
      f13ck(i,j) = p13ck(i,j)*f3(j)
    end do
  end do
  
  write(fname,"('martest',i3.3,'.dat')") itau
  open(10,file=fname,status='replace')
  do j=1,nsmp
    do k=1,nsmp
      write(10,"(6(e14.7,x))") axis1(j),axis2(k),p13(j,k),p13ck(j,k),f13(j,k),f13ck(j,k)
    end do
    write(10,*) ''
  end do
  close(10)
  

end program

!====================================================================

real*8 function epa(x)

  implicit none
  
  real*8,dimension(2) :: x
  real*8 r2
  
  r2 = x(1)*x(1) + x(2)*x(2)
  
  if (r2.lt.5.0d0) then
    epa = 5.0d0 - r2
  else
    epa = 0.0d0
  end if
  
end function




